#!/usr/bin/python
#
# Linux Desktop Testing Project http://www.gnomebangalore.org/ldtp
# 
# gldap.py - GNU Linux Desktop Automation Project
# 
#  Author:
#     A. Nagappan <anagappan@novell.com>
# 
#  Copyright 2005 Novell, Inc.
# 
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU Library General Public
#  License as published by the Free Software Foundation; either
#  version 2 of the License, or (at your option) any later version.
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#  Library General Public License for more details.
# 
#  You should have received a copy of the GNU Library General Public
#  License along with this program; if not, write to the
#  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
#  Boston, MA 02111-1307, USA.
#

import sys

if len (sys.argv) < 2:
    print 'Syntax: gldap <XML File>'
    sys.exit (1)
try:
    if sys.argv[1] == '--help' or sys.argv[1] == '-h':
        print 'Syntax: gldap <XML File>'
        sys.exit (1)
except IndexError:
    print 'Syntax: gldap <XML File>'
    sys.exit (1)    

import xml.dom.minidom

try:
    dom = xml.dom.minidom.parse (sys.argv[1])
except xml.parsers.expat.ExpatError, msg:
    print 'XML Error: ' + str (msg)
    sys.exit (1)
except IOError:
    print 'XML \"' + sys.argv[1] + '\" file not found'
    sys.exit (1)

import ldtp, ldtputils, traceback

def getText (nodelist):
    rc = ""
    for node in nodelist:
        if node.nodeType == node.TEXT_NODE:
            rc = rc + node.data
    return rc

def executeldtp (ldtpxmldata):
    ldtpxml = ldtpxmldata.getElementsByTagName ("ldtp")
    if ldtpxml == []:
        ldtp.log ('ldtp xml tag not present')
        print 'ldtp xml tag not present'
        sys.exit (1)
    logfileappend = 1
    logfilename = ''
    for ldtpelements in ldtpxml:
        try:
            logfileoverwrite = ldtpelements.getElementsByTagName ("logfileoverwrite")[0]
            logfileupdate = getText (logfileoverwrite.childNodes)
            try:
                logfileappend = int (logfileupdate)
            except ValueError:
                #print 'Log file append status not integer value - ' + logfileupdate
                log ('Log file append status not integer value - ' + logfileupdate, 'warning')
                None
            #print 'Log append - ' + logfileappend
        except IndexError:
            #print 'Log file overwrite not present'
            None
        try:
            logfile = ldtpelements.getElementsByTagName ("logfile")[0]
            logfilename = getText (logfile.childNodes)
            ldtp.startlog (logfilename, logfileappend)
            #print 'Log file name - ' + logfilename + ' - overwrite - ' + str (int (logfileappend))
        except IndexError:
            #print 'Log file entry not present'
            None
        try:
            appmapfile = ldtpelements.getElementsByTagName ("appmapfile")[0]
            appmapfilename = getText (appmapfile.childNodes)
            #print 'Appmap file name: ' + appmapfilename
            ldtp.log ('appmap file name ' + appmapfilename, 'info')
            ldtp.initappmap (appmapfilename)
        except IndexError:
            #print 'Log file entry not present'
            None
        except ldtp.error, msg:
            #print 'appmap could not be initalize ' + str (msg)
            ldtp.log ('Appmap could not be initalized ' + str (msg), 'error')
        executegroup (ldtpelements)
    if logfilename != '':
        ldtp.stoplog ()

def executegroup (ldtpelements):
        groups = ldtpelements.getElementsByTagName ("group")
        i = 1
        for groupelements in groups:
            #print 'Executing group ' + groupelements.nodeName + str (i)
            ldtp.log ('Executing ' + groupelements.nodeName + str (i), 'groupstart')
            executescript (groupelements)
            ldtp.log ('Executing ' + groupelements.nodeName + str (i), 'groupend')
            i = i + 1

def executescript (groupelements):
    scripts = groupelements.getElementsByTagName ("script")
    for scriptelements in scripts:
        scriptname = ''
        scriptdata = ''
        try:
            name = scriptelements.getElementsByTagName ("name")[0]
        except IndexError:
            #print 'Script file entry not present - skipping'
            ldtp.log ('Script file entry not present - skipping', 'warning')
            continue
        scriptname = getText (name.childNodes)
        try:
            data = scriptelements.getElementsByTagName ("data")[0]
            scriptdata = getText (data.childNodes)
        except IndexError:
            ldtp.log ('Data file maynot be present')
        scriptglobal = dict ({'datafilename' : ''})
        if scriptdata != '':
            ldtp.log (scriptname, 'scriptstart')
            ldtp.log (scriptdata, 'datafilename')
            scriptglobal = dict ({'datafilename' : scriptdata})
        else:
            ldtp.log (scriptname, 'scriptstart')
            ldtp.log ('data xml tag missing', 'warning')
        #print 'Executing script: ' + scriptname + ' - ' + scriptdata
        try:
            appmapfile = scriptelements.getElementsByTagName ("appmapfile")[0]
            appmapfilename = getText (appmapfile.childNodes)
            #print 'Appmap file name: ' + appmapfilename
            ldtp.log ('appmap file name ' + appmapfilename, 'info')
            ldtp.initappmap (appmapfilename)
        except IndexError:
            #print 'Log file entry not present'
            None
        except ldtp.error, msg:
            #print 'appmap could not be initalize ' + str (msg)
            ldtp.log ('Appmap could not be initalized ' + str (msg), 'error')
        try:
            execfile (scriptname, scriptglobal)
        except ldtputils.LdtpExecutionError:
            ldtp.log ('stopping this group execution', 'error')
            ldtp.log (scriptname, 'scriptend')
            break
        except ldtp.error, msg:
            ldtp.log (str (msg), 'error')
            ldtp.log (scriptname, 'scriptend')
            break
        except IOError:
            ldtp.log ('Script \"' + scriptname + '\" not found', 'error')
            ldtp.log (scriptname, 'scriptend')
            break
        except:
            ldtp.log (traceback.format_exc (), 'error')
            ldtp.log (scriptname, 'scriptend')
            break
        ldtp.log (scriptname, 'scriptend')

import os

sys.path = sys.path + ['.']
os.chdir (os.getcwdu ())
executeldtp (dom)
